# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_filters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import filters_common_pb2 as filters__common__pb2
from . import result_status_pb2 as result__status__pb2
from . import results_fields_pb2 as results__fields__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15results_filters.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x14\x66ilters_common.proto\x1a\x13result_status.proto\x1a\x14results_fields.proto\"\x8b\x01\n\x0c\x46ilterStatus\x12>\n\x05value\x18\x01 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterStatusOperator\"\xcb\x02\n\x0b\x46ilterField\x12\x37\n\x05\x66ield\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.results.ResultField\x12:\n\rfilter_string\x18\x02 \x01(\x0b\x32!.armonik.api.grpc.v1.FilterStringH\x00\x12\x36\n\x0b\x66ilter_date\x18\x03 \x01(\x0b\x32\x1f.armonik.api.grpc.v1.FilterDateH\x00\x12\x38\n\x0c\x66ilter_array\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.FilterArrayH\x00\x12\x42\n\rfilter_status\x18\x05 \x01(\x0b\x32).armonik.api.grpc.v1.results.FilterStatusH\x00\x42\x11\n\x0fvalue_condition\"C\n\nFiltersAnd\x12\x35\n\x03\x61nd\x18\x01 \x03(\x0b\x32(.armonik.api.grpc.v1.results.FilterField\">\n\x07\x46ilters\x12\x33\n\x02or\x18\x01 \x03(\x0b\x32\'.armonik.api.grpc.v1.results.FiltersAndB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_filters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _globals['_FILTERSTATUS']._serialized_start=120
  _globals['_FILTERSTATUS']._serialized_end=259
  _globals['_FILTERFIELD']._serialized_start=262
  _globals['_FILTERFIELD']._serialized_end=593
  _globals['_FILTERSAND']._serialized_start=595
  _globals['_FILTERSAND']._serialized_end=662
  _globals['_FILTERS']._serialized_start=664
  _globals['_FILTERS']._serialized_end=726
# @@protoc_insertion_point(module_scope)
